#![feature(proc_macro_hygiene, decl_macro)]

mod api;
mod config;
mod r#static;

use anyhow::{Context, Result};
use clap::{Arg, App, crate_version};
use rocket::routes;
use rocket::config::{Config, Environment};

use crate::config::load_config;

const DEFAULT_CONFIG_FILE_PATH: &str = "/etc/webldappasswd/config.json";

fn main() -> Result<()> {
    let matches = App::new("WebLDAPPasswd")
        .version(crate_version!())
        .arg(Arg::with_name("config")
             .short("c")
             .long("config")
             .value_name("CONFIG_FILE_PATH")
             .help("Custom configuration file")
             .takes_value(true))
        .get_matches();

    let config_file_path = matches
        .value_of("config")
        .unwrap_or(DEFAULT_CONFIG_FILE_PATH);

    let config = load_config(config_file_path)?;

    let rocket_config = Config::build(Environment::Production)
        .address(&config.host)
        .port(config.port)
        .finalize()
        .with_context(|| format!("Bad host address ({}) in configuration file '{}'", config.host, config_file_path))?;

    rocket::custom(rocket_config)
        .mount("/", routes![r#static::index,
                            r#static::legal,
                            r#static::css,
                            r#static::js,
                            r#static::checkmark,
                            r#static::cross,
                            r#static::icon,
                            r#static::hourglass,
                            api::update])
        .manage(config)
        .launch();

    Ok(())
}
